/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Felamimail **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2019-09-18 20:21+0200\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.2.3\n"

, "Out of Office reply from %1$s"
: "Abwesenheitsnotiz von %1$s"

, "You have new mail from "
: "Sie haben eine neue Nachricht von "

, "shared / adb_list accounts need to have a password set"
: "Gemeinsame Konten benötigen ein Passwort"

, "shared / adb_list accounts need to have an email set"
: "Gemeinsame Konten benötigen eine E-Mail-Adresse"

, "userInternal accounts need to have an email set"
: "Das persönliche Systemkonto benötigt eine E-Mail-Adresse"

, "Internal user accounts need a valid user"
: "Das persönliche Systemkonto benötigt einen validen Benutzer"

, "Migration of this account has not been approved!"
: "Die Migration dieses Kontos wurde nicht freigegeben!"

, "Bad recipient address syntax"
: "Empfängeradressen fehlerhaft"

, "Recipient address rejected"
: "Empfängeradresse abgelehnt"

, "Invalid address format"
: "Invalides Adressenformat"

, "Error: %s"
: "Fehler: %s"

, "Could not send message"
: "Konnte Nachricht nicht senden"

, "My Mail Download Links"
: "Meine E-Mail Download Links"

, "Answered"
: "Beantwortet"

, "Seen"
: "Gelesen"

, "Deleted"
: "Gelöscht"

, "Draft"
: "Entwurf"

, "Flagged"
: "Markiert"

, "Mailinglist Reject Reason"
: "E-Mail-Verteiler Ablehnungsgrund"

, "Your email has been rejected"
: "Ihre E-Mail wurde abgelehnt"

, "Vacation Templates Node ID"
: "Abwesenheits-Vorlalagen Node ID"

, "Email Notification Templates Node ID"
: "E-Mail Benachrichtigungs-Vorlagen Node ID"

, "Custom Vacation Message"
: "Benutzerdefnierte Abwesenheitsnotiz"

, "User is allowed to set custom vacation message for system account"
: "Der Benutzer darf eine benutzerdefinierte Abwesenheitsnotiz für das Systemkonto einstellen"

, "Cache email body"
: "E-Mail zwischenspeichern"

, "Should the email body be cached (recommended for slow IMAP server connections)"
: "Soll die E-Mail zwischengespeichert werden (empfohlen für langsame IMAP Verbindungen)"

, "Delete Archived Mail"
: "Archivierte Nachricht löschen"

, "Enabled Features"
: "Feature aktivieren"

, "Enabled Features in Felamimail Application."
: "Eingeschaltete Features für die Felamimail Anwendung."

, "Account Migration"
: "Kontomigration"

, "Shows context menu for system accounts to approve migration"
: "Zeigt Menüpunkt zur Freigabe der Kontomigration"

, "Tine 2.0 Flag"
: "Tine 2.0 Flag"

, "Add a Tine 2.0 flag to sent messages"
: "Füge eine Tine 2.0 Flag zu gesendeten Nachrichten hinzu"

, "Show Reply-To"
: "Zeige Antworten-An"

, "Show Reply-To field in message compose dialog"
: "Zeige Antwort-An Feld im Nachricht Verfassen Dialog"

, "Auto-Create Folders"
: "Automatisches Erstellen von Ordnern"

, "Create template, trash, sent, draft and junks folders for system accounts"
: "Erstellen von Vorlagen-, Papierkorb-, gesendeten, Entwurfs- und Junk-Ordnern für Systemkonten"

, "Filter E-Mail URIs"
: "E-Mail URIs filtern"

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on"
: "Sollen links in E-Mail Text gefiltert werden. Nur interne Verweise sind erlaubt wenn dies eingeschaltet wird"

, "System Account Folder Defaults"
: "Standardordner für System Nutzer"

, "Paths of the special folders (like Sent, Trash, ...)"
: "Pfad für spezielle Ordner (wie Gesendet, Mülleimer, …)"

, "Allow self signed TLS cert for IMAP connection"
: "Erlaube selbst signierte TLS Zertifikate für IMAP Verbindungen"

, "Sieve Redirect Only Internal"
: "Nur interne Sieve Weiterleitungen erlauben"

, "Allow only sieve redirect rules to internal (primary/secondary) email addresses"
: "Erlaube SIEVE Weiterleitungen nur an interne (primäre oder sekundäre E-Mail Domain) E-Mail Adressen"

, "Sieve Notification Bounces Reporting Email"
: "SIEVE Benachrichtigungen Bounce Report E-Mail"

, "URL icon path for own domain"
: "URL des icon Pfades für die eigene Domain"

, "Used to mark messages from configured primary and secondary domains"
: "Wird genutzt um Nachrichten zu markieren die von der konfigurierten primären oder sekundären Domain stammen"

, "URL icon path for other domains"
: "URL des icon Pfades für andere Domains"

, "Used to mark messages from all other domains"
: "Wird genutzt um Nachrichten zu markieren die von anderen Domains stammen"

, "Other domain regex for FLAG_ICON_OTHER_DOMAIN"
: "Regulärer Ausdruck für andere Domains FLAG_ICON_OTHER_DOMAIN"

, "Can not combine \"allow external\" and \"allow only members\""
: "\"Externe E-Mails weiterleiten\" und \"Nur E-Mails von Gruppenmitgliedern weiterleiten\" können nicht kombiniert werden"

, "Signature, Signatures"
: [
  "Signatur"
 ,"Signaturen"

]
, "Name"
: "Name"

, "Is default"
: "Ist Standard"

, "Reading Confirmation:"
: "Lesebestätigung:"

, "Your message:"
: "Ihre Nachricht:"

, "Received on"
: "Erhalten am"

, "Was read by:"
: "Wurde gelesen von:"

, "on"
: "am"

, "Message File Location, Message File Locations"
: [
  "Ablageort der Nachricht"
 ,"Ablageorte der Nachricht"

]
, "Message File Locations"
: "Nachrichten Ablageorte"

, "Message ID Hash"
: "Nachrichten Hash ID"

, "Message ID"
: "Nachrichten ID"

, "Model"
: "Model"

, "Record ID"
: "Datensatz ID"

, "Record Title"
: "Datensatz Titel"

, "Node ID"
: "Node ID"

, "Type"
: "Typ"

, "Account, Accounts"
: [
  "Konto"
 ,"Konten"

]
, "Email Account, Email Accounts"
: [
  "E-Mail-Konto"
 ,"E-Mail-Konten"

]
, "User"
: "Benutzer"

, "Migration Approved"
: "Migration freigegeben"

, "IMAP Host"
: "IMAP Host"

, "IMAP Port"
: "IMAP-Port"

, "IMAP SSL"
: "IMAP SSL"

, "Sent Folder"
: "Gesendet Ordner"

, "Trash Folder"
: "Mülleimer Ordner"

, "Drafts Folder"
: "Entwürfe Ordner"

, "Templates Folder"
: "Vorlagen Ordner"

, "Display Format"
: "Anzeigeformat"

, "Compose Format"
: "Textformat"

, "Preserve Format"
: "Format beibehalten"

, "Reply-To"
: "Antwortadresse"

, "E-Mail"
: "E-Mail"

, "From"
: "Von"

, "Organization"
: "Firma"

, "Signatures"
: "Signaturen"

, "Signature Position"
: "Signaturposition"

, "SMTP Host"
: "SMTP Host"

, "SMTP Port"
: "SMTP Port"

, "SMTP SSL"
: "SMTP-SSL"

, "SMTP Authentication"
: "SMTP-Authentifizierung"

, "Sieve Host"
: "Sieve Host"

, "Sieve Port"
: "Sieve-Port"

, "Sieve SSL"
: "Sieve-SSL"

, "Message File Suggestion, Message File Suggestions"
: [
  "Vorschlag für Ablageort"
 ,"Vorschlage für Ablageorte"

]
, "Message File Suggestions"
: "Vorschläge für Ablageorte"

, "All inboxes of my email accounts"
: "Alle Posteingänge meiner Konten"

, "All unread mail"
: "Alle ungelesenen Nachrichten"

, "All unread mail of my email accounts"
: "Alle ungelesenen Nachrichten meiner Konten"

, "All highlighted mail"
: "Alle markierten Nachrichten"

, "All highlighted mail of my email accounts"
: "Alle markierten Nachrichten meiner Konten"

, "All drafts"
: "Alle Entwürfe"

, "All mails with the draft flag"
: "Alle Nachrichten mit dem Entwurfs-Flag"

, "manage email accounts"
: "Konten verwalten"

, "Edit and delete email accounts"
: "Bearbeiten und Löschen von Konten"

, "Add email accounts"
: "Konten hinzufügen"

, "Create new email accounts"
: "Neue Konten hinzufügen"

, "Compose email"
: "Nachricht verfassen"

, "To"
: "An"

, "CC"
: "CC"

, "BCC"
: "BCC"

, "Mass Mailing"
: "Massen-Mail"

, "Delete"
: "Löschen"

, "Reply"
: "Antworten"

, "Reply To All"
: "Allen antworten"

, "Forward"
: "Weiterleiten"

, "Print Message"
: "Nachricht drucken"

, "Print Preview"
: "Druckvorschau"

, "(new message)"
: "(neue Nachricht)"

, "Select recipients for \"{0}\""
: "Empfänger für \"{0}\" auswählen"

, "Cancel"
: "Abbruch"

, "Ok"
: "Ok"

, "Folders of account {0}"
: "Ordner von Konto {0}"

, "Folders of all accounts"
: "Ordner aller Konten"

, "Empty Folder"
: "Ordner leeren"

, "Add Folder"
: "Ordner hinzufügen"

, "New {0}"
: "Neuer {0}"

, "Folder, Folders"
: [
  "Ordner"
 ,"Ordner"

]
, "Please enter the name of the new {0}:"
: "Bitte tragen Sie einen Namen für den neuen {0} ein:"

, "No {0} added"
: "Kein {0} hinzugefügt"

, "You have to supply a {0} name!"
: "Sie müssen einen {0}-Namen eingeben!"

, "Please wait"
: "Bitte warten"

, "Creating {0}..."
: "Erstelle {0} ..."

, "Edit Account"
: "Konto bearbeiten"

, "Edit Vacation Message"
: "Abwesenheitsnotiz bearbeiten"

, "Edit Filter Rules"
: "Filterregeln bearbeiten"

, "Notifications"
: "Benachrichtigungen"

, "Mark Folder as read"
: "Ordner als gelesen markieren"

, "Update Folder List"
: "Ordnerliste aktualisieren"

, "Approve Migration"
: "Migration freigeben"

, "Send"
: "Senden"

, "Search Recipients"
: "Suche Empfänger"

, "Save As Draft"
: "Als Entwurf speichern"

, "Save As Template"
: "Als Vorlage speichern"

, "Reading Confirmation"
: "Lesebestätigung"

, "Activate this toggle button to receive a reading confirmation."
: "Aktivieren Sie diesen Knopf um eine Lesebestätigung zu erhalten."

, "Encrypt Email"
: "Nachricht verschlüsseln"

, "Encrypt email using Mailvelope"
: "Nachricht mit Mailvelope verschlüsseln"

, "Activate this toggle button to send the mail as separate mail to each recipient."
: "Wenn der Knopf gedrückt ist, bekommt jeder Empfänger seine eigene einzelne Kopie der Nachricht."

, "Click to search for and add recipients from the Addressbook."
: "Klicken um Empfänger im Adressbuch zu suchen und zur Empfängerliste hinzuzufügen."

, "Encrypted Content"
: "Verschlüsselter Inhalt"

, "Discard this Draft?"
: "Diesen Entwurf verwerfen?"

, "Do you want to discard the current draft?"
: "Möchten sie den aktuellen Entwurf verwerfen?"

, "Loading Mail Addresses"
: "Lade E-Mail-Adressen"

, "Fwd:"
: "Fwd:"

, "{0} Message"
: "{0} Nachricht"

, "Failed"
: "Fehlgeschlagen"

, "{0} account setting empty."
: "{0} E-Mailaccount-Einstellung leer."

, "Files are still uploading."
: "Es werden gerade Dateien hochgeladen."

, "{locationCount, plural, one {This message will be filed at the following location} other {This message will be filed at the following locations}}: {locationsHtml}"
: "{locationCount, plural, one {Diese Nachricht wird an folgendem Ort abgelegt} other {Diese Nachricht wird an folgenden Orten abgelegt}}: {locationsHtml}"

, "On {0}, {1} wrote"
: "Am {0}, schrieb {1}"

, "Original message"
: "Originalnachricht"

, "Compose email:"
: "Nachricht verfassen:"

, "Attachments"
: "Anhänge"

, "None"
: "Keine"

, "Convert to formated text"
: "In formatierten Text konvertieren"

, "Body"
: "Nachricht"

, "NOTE: This is mail will be sent as a mass mail, i.e. each recipient will get his or her own copy."
: "Beachte: Diese Nachricht wird als Massen-Mail verschickt. So bekommt z.b. jeder Empfänger seine eigene einzelne Kopie."

, "Reply-To Email"
: "Antwortadresse"

, "Add email address here for reply-to"
: "Antwortadresse hier eintragen (reply-to)"

, "Subject"
: "Betreff"

, "Warning"
: "Warnung"

, "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
: "Einige Anhänge sind vom Typ \"Systenlink\". Einige Empfänger (gelb markiert) sind keine Benutzer dieser Instanz. Nur Empfänger mit einem aktiven Benutzerkonto können diese Links öffnen."

, "Do you really want to send?"
: "Wollen Sie die Nachricht wirklich absenden?"

, "Empty subject"
: "Leerer Betreff"

, "Do you really want to send a message with an empty subject?"
: "Wollen Sie die Nachricht wirklich mit einem leeren Betreff senden?"

, "No recipients set."
: "Empfänger fehlen."

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: "Die Nachricht kann nicht verschlüsseltet werden. Die öffentliche Schlüssel für die folgenden Empfänger fehlen: {0}"

, "Click here to set To/CC/BCC."
: "Hier klicken um An/CC/BCC zu setzen."

, "To:"
: "An:"

, "Cc:"
: "Cc:"

, "Bcc:"
: "Bcc:"

, "Remove"
: "Entfernen"

, "From (Email)"
: "Von (E-Mail)"

, "From (Email and Name)"
: "Von (E-Mail und Name)"

, "To (Email)"
: "An (E-Mail)"

, "To (Email CC)"
: "An (E-Mail CC)"

, "Size"
: "Größe"

, "Header contains"
: "Header enthält"

, "Header name"
: "Headername"

, "Header value"
: "Headerinhalt"

, "Header regex"
: "Header Regulärer Ausdruck"

, "Notification for {0}"
: "Benachrichtigung für {0}"

, "Notification Email"
: "Benachrichtigungs E-Mail"

, "Edit Filter Rule"
: "Filterregel bearbeiten"

, "Apply filter if"
: "Wende Filter an, wenn"

, "all conditions match"
: "alle Bedingungen erfüllt sind"

, "any condition matches"
: "mindestens eine Bedingung erfüllt ist"

, "Do this action:"
: "Führe diese Aktion aus:"

, "Keep a copy"
: "Kopie  zurückbehalten"

, "Move mail to folder"
: "Nachricht in Ordner verschieben"

, "Redirect mail to address"
: "Nachricht an folgende Adresse weiterleiten"

, "Reject mail with this text"
: "Nachricht mit folgendem Text ablehnen"

, "Discard mail"
: "Nachricht verwerfen"

, "Auto-Reply mail with this text"
: "Nachricht mit folgendem Text beantworten"

, "Keep mail"
: "Nachricht behalten"

, "Vacation Message for {0}"
: "Abwesenheitsnotiz für {0}"

, "General"
: "Allgemein"

, "Advanced"
: "Erweitert"

, "Only send all X days to the same sender"
: "Nur alle X Tage an den gleichen Absender schicken"

, "Incoming mails will be answered with this text:"
: "Eingehende E-Mails werden mit folgendem Text beantwortet:"

, "Status"
: "Status"

, "I am available (vacation message disabled)"
: "Ich bin verfügbar (Abwesenheitsnotiz inaktiv)"

, "I am not available (vacation message enabled)"
: "Ich bin nicht verfügbar (Abwesenheitsnotiz aktiv)"

, "Start Date"
: "Startdatum"

, "Set vacation start date ..."
: "Startdatum der Abwesenheit …"

, "End Date"
: "Enddatum"

, "Set vacation end date ..."
: "Enddatum der Abwesenheit …"

, "Representative #1"
: "Vertretungsperson #1"

, "Choose first Representative ..."
: "Wählen Sie die erste Vertretungsperson …"

, "Representative #2"
: "Vertretungsperson #2"

, "Choose second Representative ..."
: "Wählen Sie die zweite Vertretungsperson …"

, "Message Template"
: "Abwesenheitsnotizvorlage"

, "Choose Template ..."
: "Abwesenheitsnotizvorlage auswählen …"

, "Sieve Filter Rules"
: "Sieve Filterregeln"

, "Sieve Filter Rules for {0}"
: "Sieve Filterregeln für {0}"

, "Move up"
: "Hoch"

, "Move down"
: "Runter"

, "Enable"
: "Aktivieren"

, "Disable"
: "Deaktivieren"

, "ID"
: "ID"

, "Conditions"
: "Bedingungen"

, "Action"
: "Aktion"

, "is greater than"
: "ist größer als"

, "is less than"
: "ist weniger als"

, "Header \"{0}\" contains \"{1}\""
: "Header \"{0}\" enthält \"{1}\""

, "Header \"{0}\" matches \"{1}\""
: "Header \"{0}\" enthält \"{1}\""

, "Message not available."
: "Nachricht nicht verfügbar."

, "Is Default"
: "Ist Standard"

, "Add Signature"
: "Signatur zufügen"

, "Edit Signature"
: "Signatur bearbeiten"

, "Delete Signature"
: "Signatur löschen"

, "Save Message as"
: "Nachricht speichern als"

, "Download"
: "Herunterladen"

, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
: "{messageCount, plural, one {Nachricht wurde gespeichert} other {# Nachrichten wurden gespeichert}}"

, "Success"
: "Erfolgreich"

, "Error"
: "Fehler"

, "Save Messages as Attachment"
: "Nachrichten als Anhang speichern"

, "Add New Account"
: "Neues Konto hinzufügen"

, "User needs to enter credentials after login"
: "Der Benutzer muss sein Passwort nach dem Login setzen"

, "Permissions"
: "Zugriffsrechte"

, "Account Name"
: "Kontoname"

, "Account Type"
: "Kontotyp"

, "Do you want to approve the migration of this account?"
: "Möchten Sie die Migration dieses E-Mail-Kontos freigeben?"

, "User Email"
: "E-Mail Adresse"

, "User Name (From)"
: "E-Mail Absender"

, "User Name (From) cannot contain a comma."
: "E-Mail Absender darf kein Komma enthalten"

, "Signature position"
: "Signaturposition"

, "Above the quote"
: "Über dem Zitat"

, "Below the quote"
: "Unter dem Zitat"

, "IMAP"
: "IMAP"

, "Host"
: "Host"

, "Port (Default: 143 / SSL: 993)"
: "Port (Standard: 143 / SSL: 993)"

, "Secure Connection"
: "Sichere Verbindung"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Username"
: "Benutzername"

, "Password"
: "Passwort"

, "SMTP"
: "SMTP"

, "Port (Default: 25)"
: "Port (Standard: 25)"

, "Authentication"
: "Authentifizierung"

, "Login"
: "Login"

, "Plain"
: "Klartext"

, "Username (optional)"
: "Benutzername (optional)"

, "Password (optional)"
: "Passwort (optional)"

, "Sieve"
: "Sieve"

, "Port (Default: 2000)"
: "Port (Standard: 2000)"

, "Other Settings"
: "Andere Einstellungen"

, "Sent Folder Name"
: "'Gesendet' Ordnername"

, "Trash Folder Name"
: "'Papierkorb' Ordnername"

, "Drafts Folder Name"
: "'Entwürfe' Ordnername"

, "Templates Folder Name"
: "'Vorlagen' Ordnername"

, "HTML"
: "HTML"

, "Plain Text"
: "Nur Text"

, "Depending on content type (experimental)"
: "Abhängig vom Content-Typ (experimentell)"

, "No"
: "Nein"

, "Yes"
: "Ja"

, "Migration has not been approved."
: "Die Migration wurde noch nicht freigegeben"

, "It is not possible to convert the account to this type yet."
: "Es ist noch nicht möglich, das Konto in diesen Typ umzuwandeln."

, "System accounts cannot be created manually."
: "Systemkonten können nicht manuell angelegt werden."

, "Account type change not possible"
: "Wechsel zu diesem Kontotyp nicht möglich"

, "E-Mail account needs a password"
: "Das E-Mail-Konto benötigt ein Passwort"

, "Use"
: "Verwenden"

, "The grant use the shared email account"
: "Das Recht um den gemeinsamen E-Mail-Account zu verwenden"

, "Edit"
: "Bearbeiten"

, "The grant edit the shared email account"
: "Das Recht um den gemeinsamen E-Mail-Account zu bearbeiten"

, "Send Mails"
: "E-Mails senden"

, "The grant to send mails via the email account"
: "Das Recht um mit dem E-Mail-Konto E-Mails zu versenden"

, "Recipient filter"
: "Empfängerfilter"

, "All recipients"
: "Alle Empfänger"

, "\"{0}\" recipients"
: "\"{0}\" Empfänger"

, "Open in Felamimail"
: "Im E-Mail-Modul öffnen"

, "Add"
: "Hinzufügen"

, "Add contact to addressbook"
: "Kontakt zum Adressbuch hinzufügen"

, "Date"
: "Datum"

, "Show or hide header information"
: "Ein/Ausblenden der E-Mail-Header"

, "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
: "{locationCount, plural, one {Diese Nachricht ist an folgendem Ort abgelegt} other {Diese Nachricht ist an folgenden Orten abgelegt}}: {locationsHtml}"

, "Add as \"To\""
: "Als \"To\" hinzufügen"

, "Add as \"Cc\""
: "Als \"Cc\" hinzufügen"

, "Add as \"Bcc\""
: "Als \"Bcc\" hinzufügen"

, "Remove from recipients"
: "Aus der Empfängerliste entfernen"

, "New Mail"
: "Neue Nachricht"

, "Email"
: "E-Mail"

, "Active Vacation Message"
: "Aktive Abwesenheitsbenachrichtigung"

, "Email account \"{0}\" has an active vacation message."
: "E-Mailkonto {0} hat eine aktive Abwesenheitsbenachrichtigung."

, "Poll URL: {0}"
: "Umfrage Link: {0}"

, "{0} as default mailer"
: "{0} als default Mailer"

, "New mails"
: "Neue Nachrichten"

, "You got {0} new mail(s) in folder {1} ({2})."
: "Sie haben {0} neue Nachricht(en) im Ordner {1} ({2})"

, "IMAP Credentials for {0}"
: "Empfangsserver-Zugangsdaten (IMAP) für {0}"

, "Credentials"
: "Zugangsdaten"

, "IMAP Error"
: "IMAP-Fehler (Empfangsserver)"

, "No connection to IMAP server."
: "Keine Verbindung zum Empfangsserver-Server (IMAP)."

, "IMAP Credentials Error"
: "Zugangsdaten für Empfangsserver (IMAP) falsch"

, "Your email credentials are wrong. Please contact your administrator"
: "Ihre E-Mail-Zugangsdaten sind falsch. Bitte kontaktieren Sie Ihren Administrator"

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: "Einer Ihrer Ordner wurde von einem anderen Client gelöscht oder umbenannt.  Bitte aktualisieren Sie die Ordnerliste."

, "SMTP Error"
: "SMTP-Fehler (Sendeserver)"

, "No connection to SMTP server."
: "Keine Verbindung zum Sendeserver (SMTP)."

, "Sieve Error"
: "Sieve-Fehler"

, "No connection to Sieve server."
: "Keine Verbindung zum Sieve-Server."

, "Save Sieve Script Error"
: "Fehler beim Speichern des Sieve-Skriptes"

, "Could not save script on Sieve server."
: "Konnte das Sieve-Skript nicht auf dem Server speichern."

, "Mailvelope decryption Error [{0}]"
: "Mailvelope Entschlüsselungs-Fehler [{0}]"

, "To decrypt this message please install {0} with API support enabled"
: "Bitte installieren Sie {0} mit aktivierter API Unterstützung um diese Nachricht zu entschlüsseln"

, "PGP encrypted Message"
: "PGP verschlüsselte Nachricht"

, "Encrypted Message"
: "Verschlüsselte Nachricht"

, "Shared System Account"
: "Gemeinsames Systemkonto"

, "Additional Personal System Account"
: "Persönliches Extra-Systemkonto"

, "Additional Personal External Account"
: "Persönliches externes E-Mail-Konto"

, "Default Personal System Account"
: "Persönliches Standard-Systemkonto"

, "Mailinglist"
: "E-Mail-Verteiler"

, "Message, Messages"
: [
  "Nachricht"
 ,"Nachrichten"

]
, "Subject/From"
: "Betreff/Von"

, "From (Name)"
: "Von (Name)"

, "Cc"
: "Kopie"

, "Bcc"
: "Blindkopie"

, "Flags"
: "Flags"

, "Received"
: "Empfangen"

, "INBOX"
: "Posteingang"

, "Drafts"
: "Entwürfe"

, "Sent"
: "Gesendet"

, "Templates"
: "Vorlagen"

, "Junk"
: "Unerwünschtes"

, "Trash"
: "Mülleimer"

, "record list, record lists"
: [
  "Nachrichtenliste"
 ,"Nachrichtenlisten"

]
, "Vacation, Vacations"
: [
  "Abwesenheitsnotiz"
 ,"Abwesenheitsnotizen"

]
, "Rule, Rules"
: [
  "Regel"
 ,"Regeln"

]
, "Flag, Flags"
: [
  "Flag"
 ,"Flags"

]
, "Flag list, Flag lists"
: [
  "Flag-Liste"
 ,"Flag-Listen"

]
, "Filemanager (Download link)"
: "Dateimanager (Download Link)"

, "Filemanager (Download link, password)"
: "Dateimanager (Download Link, Passwort)"

, "Filemanager (Systemlink)"
: "Dateimanager (System Link)"

, "Attachment Type"
: "Anhang Typ"

, "Click icon to change"
: "Zum Ändern auf die Zeile klicken"

, "name"
: "Name"

, "size"
: "Größe"

, "type"
: "Typ"

, "Failure"
: "Fehler"

, "This file is already attached to this record."
: "Diese Datei ist bereits an diesen Datensatz angehängt."

, "No Messages found."
: "Keine Nachrichten gefunden."

, "Compose"
: "Verfassen"

, "Toggle highlighting"
: "Markierung an/aus"

, "Mark read/unread"
: "(Un)gelesen markieren"

, "Move"
: "Verschieben"

, "Add Account"
: "Konto hinzufügen"

, "Id"
: "Id"

, "Sender"
: "Absender"

, "Forwarded"
: "Weitergeleitet"

, "Tine20"
: "Tine20"

, "Filed as:"
: "Abgelegt unter:"

, "Select Message File Location"
: "Ablageort für Nachricht auswählen"

, "Filing Messages"
: "Speichere Nachrichten"

, "Error Filing Message"
: "Fehler beim Speichern von Nachrichten"

, "Could not file message."
: "Konnte Nachrichten nicht ablegen."

, "Send Reading Confirmation"
: "Sende Lesebestätigung"

, "Do you want to send a reading confirmation message?"
: "Wollen Sie eine Lesebestätigung senden?"

, "Total Messages:"
: "Nachrichten insgesamt:"

, "Unread Messages:"
: "Ungelesene Nachrichten:"

, "Name on Server:"
: "Name auf dem Server:"

, "Last update:"
: "Zuletzt aktualisiert:"

, "Fetching messages... ({0} done)"
: "Lade Nachrichten … ({0} erledigt)"

, "{0} unread message, {0} unread messages"
: [
  "{0} ungelesene Nachricht"
 ,"{0} ungelesene Nachrichten"

]
, "All inboxes"
: "Alle Posteingänge"

, "Default Font"
: "Standardschriftart"

, "Setting the default font in the E-Mail app"
: "Einstellung für die Standardschriftart im der E-Mail-Modul"

, "Default Email Account"
: "Standard E-Mailkonto"

, "The default email account to use when sending mails."
: "Das Standard E-Mailkonto für das Versenden von E-Mails."

, "Mark Email Automatically As Read"
: "E-Mails automatisch als gelesen markieren"

, "Is email marked as read automatically or by user action"
: "Wird die E-Mail automatisch als gelesen markiert oder ist eine Benutzeraktion nötig"

, "Email Update Interval"
: "E-Mail Aktualisierungsintervall"

, "How often should Felamimail check for new Emails (in minutes)."
: "Wie oft Felamimail nach neuen E-Mails schauen soll (in Minuten)."

, "Use for mailto links"
: "Für mailto: Verweise verwenden"

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: "Felamimail für mailto: Verweise verwenden oder externes E-Mailprogramm verwenden."

, "Use for NOTES"
: "E-Mail-Notiz erzeugen"

, "Save Note default Value."
: "Es wird standardmäßig eine E-Mail-Notiz beim Versenden einer Nachricht erzeugt."

, "Confirm Delete"
: "Löschen bestätigen"

, "Show confirmation dialog when deleting mails."
: "Beim löschen von Nachrichten einen Bestätigungsdialog anzeigen."

, ".eml file Attachment in forwarded mails"
: ".eml Dateianhang in weitergeleiteten Mails"

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: "Hänge eine .eml Datei an eine weitergleitete Mail an. Alle anderen Anhänge seperat"

, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
: "{attachmentCount, plural, one {Anhang wurde gespeichert} other {# Anhänge wurden gespeichert}}"

, "Save As"
: "Speichern als"

, "File (in Filemanager) ..."
: "Datei (im Dateimanager) ..."

, "Attachment (of Record)"
: "Anhang (eines Datensatzes)"

, "Save as Record Attachment"
: "Als Datensatz Anhang speichern"

, "Folder with name {0} already exists!"
: "Ordner mit dem Namen {0} ist bereits vorhanden!"

, "Failure on create folder"
: "Fehler beim anlegen des Ordners"

, "Convert this account to a shared account. Please set a new password for the account:"
: "Dieses Konto in einen gemeinsamen Account umwandeln. Bitte setzen Sie ein neues Passwort:"

, "New Password"
: "Neues Passwort"

, "Converting Account ..."
: "Konto wird umgewandelt ..."

, "Convert Account"
: "Konto umwandeln"

, "This alias can be used for sending e-mails."
: "Dieser Alias kann zum versenden von E-Mails genutzt werden."

, "Auto-move notifications"
: "Automatisches Verschieben von Benachrichtigungen"

, "Auto-move notifications folder"
: "Ordner für Benachrichtigungen"

, "It is not allowed to redirect emails to self! Please change the recipient."
: "Es ist nicht erlaubt, E-Mails an sich selbst weiterzuleiten. Bitte ändern Sie den Empfänger."

, "Redirects to external email domains are not allowed."
: "Weiterleitungen zu externen E-Mail-Konten sind nicht erlaubt."

, "It is not allowed to copy e-mails in the same account."
: "E-Mails innerhalb eines Kontos zu kopieren ist nicht erlaubt."

, "Copy"
: "Kopieren"

, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
: "Diese Nachricht ist möglicherweise SPAM. Bitte helfen Sie, das Anti-SPAM-System mit Ihrer Entscheidung zu trainieren: \"Ja, es ist SPAM\" oder \"Nein, kein SPAM\""

, "Yes, it is SPAM"
: "Ja, es ist SPAM"

, "No, it is not"
: "Nein, kein SPAM"

, "It is SPAM"
: "Es ist SPAM"

, "It is not SPAM"
: "Kein SPAM"

, "Confirm SPAM Suspicion"
: "SPAM Verdacht bestätigen"

, "This message might be SPAM"
: "Bei dieser Nachricht könnte es sich um SPAM handeln"

, "GENDER_Message"
: "female"

, "Test IMAP Connection"
: "IMAP-Verbindung testen"

, "Test SMTP Connection"
: "SMTP-Verbindung testen"

, "Server connection failed. Do you still want to save this setting and exit?"
: "Server-Verbindung fehlgeschlagen. Möchten Sie die Einstellungen trotzdem speichern?"

, "Connection succeed"
: "Verbindung erfolgreich"

, "Connection failed"
: "Verbindung fehlgeschlagen"

, "{server} Connection Status"
: "{server} Verbindungsstatus"

, "Credentials missing"
: "Zugangsdaten fehlen"

, "Hostname missing"
: "Hostname fehlt"

, "Connecting to {0} server..."
: "Verbindung zu {0} Server wird aufgebaut..."

, "It is not possible to convert the account to this type."
: "Es ist nicht möglich, das Konto in diesen Typ umzuwandeln."

, "Dear user,"
: "Lieber Benutzer,"

, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
: "%1$s ist aufgefallen, dass die eingerichtete Daten-Syncronisation auf Ihrem Gerät nicht mehr aktiv arbeitet. Bitte starten Sie die Syncronisation auf Ihrem Gerät noch einmal neu."

, "Thank you."
: "Besten Dank."

, "Your %1$s Team"
: "Ihr %1$s Team"

, "Internal user accounts need an email address"
: "Interne Benutzerkonten brauchen eine E-Mail-Adresse"

, "Internal user accounts need to be assigned to a user"
: "Interne Benutzerkonten müssen einer Nutzer:in zugeordnet sein"

, "Import Messages"
: "Nachrichten importieren"

, "No target folder selected"
: "Kein Zielordner ausgewählt"

, "You need to select a target folder for the messages."
: "Sie müssen einen Zielordner für die Nachrichten auswählen."

, "Wrong File Type"
: "Falscher Dateityp"

, "Files of type eml allowed only."
: "Nur Dateien vom Typ eml sind erlaubt."

, "Importing Messages..."
: "Importiere Nachrichten..."

, "Attachment"
: "Anhang"

, "GENDER_Folder"
: "male"

, "Attention"
: "Achtung"

, "The from-address for this mail got changed to {0} , as you don't have the send mail right for the account {1}."
: "Die Absender-Adresse für diese Mail wurde auf : {0} geändert, \n da sie für das Konto : {1} nicht das E-Mail Versenden Recht haben."

, "Only password download link"
: "Nur passwortgeschützter Download Link"

, "userInternal accounts need to have an user_id set"
: "Das persönliche Systemkonto benötigen eine User-ID"

, "Original message not found, email was moved or deleted"
: "Die ursprüngliche Nachricht wurde nicht gefunden, die E-Mail wurde verschoben oder gelöscht."

, "IMAP Hostname missing"
: "IMAP Hostname fehlt"

, "IMAP Credentials missing"
: "IMAP Zugangsdaten fehlen"

, "SMTP Hostname missing"
: "SMTP Hostname fehlt"

, "SMTP Credentials missing"
: "SMTP Zugangsdaten fehlen"

, "Allow only password download links"
: "Nur passwortgeschützter Download Link erlaubt"

, "Folder with this name already exists!"
: "Ordner mit dem Namen ist bereits vorhanden!"

, "Manage personal email accounts"
: "Persönliche Konten verwalten"

, "Edit and delete personal email accounts"
: "Bearbeiten und Löschen von persönlichen Konten"

, "Add personal email accounts"
: "Persönliche Konten hinzufügen"

, "Create new personal email accounts"
: "Neue persönliche Konten hinzufügen"

, "Explore Sieve script"
: "Sieve-Skript anzeigen"

, "Signature"
: "Signatur"

, "Message File Location"
: "Ablageort der Nachricht"

, "Account"
: "Konto"

, "Email Account"
: "E-Mail-Konto"

, "Message File Suggestion"
: "Vorschlag für Ablageort"

, "Folder"
: "Ordner"

, "Message"
: "Nachricht"

, "record list"
: "Nachrichtenliste"

, "Vacation"
: "Abwesenheitsnotiz"

, "Rule"
: "Regel"

, "Flag"
: "Flag"

, "Flag list"
: "Flag-Liste"

, "{0} unread message"
: "{0} ungelesene Nachricht"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
